@@ -1,6 +1,6 @@
 #' Compute the robust effect size index estimate from chi-squared statistic.
 #'
-#' This function computes the robust effect size index from Vandekar, Rao, & Blume (2020).
+#' This function computes the robust effect size index from Vandekar, Tao, & Blume (2020).
 #' Vector arguments are accepted. If different length arguments are passed they are dealt with in the usual way of R.
 #' For mixed effects models, RESI is conditional on the average correlation
 #' structure within subjects.
@@ -16,7 +16,7 @@
 #' mod = lm(charges ~ region * age + bmi + sex, data = RESI::insurance)
 #'
 #' # run a Wald test with robust variance
-#' wt = lmtest::waldtest(mod, vcov = sandwich::vcovHC, test = 'Chisq')
+#' wt = lmtest::waldtest(mod, vcov = sandwich::vcovHC, test = "Chisq")
 #'
 #' # get Chi-sq value and degrees of freedom
 #' chisq = wt$Chisq[2]
@@ -27,6 +27,9 @@
 #'
 #' @export
 chisq2S <- function(chisq, df, n){
+  if (any(chisq < 0)){
+    stop("\nChi-square statistic must be non-negative")
+  }
   S = (chisq - df)/n
   sqrt(ifelse(S<0, 0, S))
 }
